import React from "react";
import { Wikis, Chat, Scales, Flash } from "@carbon/icons-react";
import { Link } from "@components/Link";

interface FeatureProps {
  title: string;
  description: string;
  href?: string;
  icon: string;
  className?: string;
}

export const Feature: React.FC<FeatureProps> = ({
  title,
  description,
  icon,
  href,
  className,
}) => {
  const ICON_SIZE = 24;
  const ICON_MAP: Record<string, React.ReactNode> = {
    wikis: <Wikis size={ICON_SIZE} />,
    chat: <Chat size={ICON_SIZE} />,
    scales: <Scales size={ICON_SIZE} />,
    flash: <Flash size={ICON_SIZE} />,
  };
  return (
    <div className={`flex flex-row ${className}`}>
      <div className="w-12 h-12 aspect-square rounded-md bg-red-500 flex justify-center items-center text-white">
        {ICON_MAP[icon]}
      </div>
      <div className="grow ml-4">
        <h5 className="font-plex text-lg leading-6 font-medium text-grey-900">
          {title}
        </h5>
        <p className="mt-2.5 text-grey-500 font-plex text-base leading-6 font-normal xl:text-grey-900">
          {description}{" "}
          {href && (
            <span className="hidden xl:inline-block">
              <Link to={href}>Learn more</Link>
            </span>
          )}
        </p>
      </div>
    </div>
  );
};
