import React from "react";

interface GridProps {
  columns: 2 | 3 | 4 | 5 | 6;
  customResponsiveColumn?: string;
  customGap?: string;
  children: React.ReactNode;
}

export const Grid: React.FC<GridProps> = ({
  columns,
  customGap = "",
  customResponsiveColumn = "",
  children,
}) => {
  const GRID_MAPPING: Record<string, string> = {
    2: "grid sm:grid-cols-2",
    3: "grid xl:grid-cols-3",
    4: "grid xl:grid-cols-4",
    5: "grid xl:grid-cols-5",
    6: "grid xl:grid-cols-6",
  };
  const RESPONSIVE_MAPPING: Record<string, string> = {
    2: "",
    3: "sm:grid-cols-2",
    4: "grid-cols-2",
    5: "grid-cols-2 sm:grid-cols-3",
    6: "grid-cols-2 sm:grid-cols-4",
  };
  return (
    <div
      className={`${GRID_MAPPING[columns]} ${
        customResponsiveColumn
          ? customResponsiveColumn
          : RESPONSIVE_MAPPING[columns]
      } ${customGap ? customGap : "gap-8 sm:gap-12"}`}
    >
      {children}
    </div>
  );
};
