import React from "react";
import { HeroSection } from "@components/HeroSection";
import { Breadcrumbs } from "./Breadcrumbs";
import { INews } from "@interfaces/INews";
import { HorizontalNewsCard } from "@components/HorizontalNewsCard";
import { TagCloud } from "@components/TagCloud";

interface HorizontalCardListViewProps {
  titleImage: string;
  subtitle: string;
  title: string;
  cards: INews[];
  tags?: Array<{ target?: string; title: string }>;
  breadcrumbs?: Array<{ target?: string; title: string }>;
  imageTag?: string;
  onTagEnable?: (tag: string) => void;
  onTagDisable?: (tag: string) => void;
  activeTags?: Array<string>;
}

export const HorizontalCardListView: React.FC<HorizontalCardListViewProps> = ({
  titleImage,
  title,
  subtitle,
  cards,
  tags,
  breadcrumbs,
  imageTag,
  onTagEnable,
  onTagDisable,
  activeTags
}) => {
  return (
    <div className="w-full mb-10 xl:mb-0">
      <HeroSection src={titleImage} imageTag={imageTag} />
      <section>
        <div className="container flex justify-between">
          <div className="w-full xl:w-[60%] mx-auto">
            <Breadcrumbs className="mt-4" crumbs={breadcrumbs} />
            <div className="mt-10 text-center">
              <span className="block font-karla text-blue-500 text-base leading-6 font-semibold tracking-wide uppercase mb-4">
                {subtitle}
              </span>
              <h2 className="font-karla text-grey-900 text-3xl sm:text-4xl xl:text-6xl leading-none font-bold tracking-tight">
                {title}
              </h2>
            </div>
            {Boolean(tags) && (
              <div className="my-11 sm:my-16">
                <TagCloud
                  tags={tags}
                  activeTags={activeTags}
                  onTagEnable={onTagEnable}
                  onTagDisable={onTagDisable}
                />
              </div>
            )}
            <div className="mt-10 mb-20 xl:mb-44">
              <div className="grid grid-cols-1 auto-rows-fr gap-7">
                {cards.map((card) => (
                  <HorizontalNewsCard
                    key={card.id}
                    type={card.type}
                    image={card.image}
                    title={card.title}
                    description={card.description}
                    time={card.time}
                    location={card.location}
                    category={card.category}
                    href={card.href}
                  />
                ))}
              </div>
            </div>
          </div>
        </div>
      </section>
    </div>
  );
};
