import React, { CSSProperties, useEffect, useState } from "react";
import { Image } from "@components/Image";
import type { IImage } from "@interfaces/IImage";
import { useKeenSlider } from "keen-slider/react";

interface ImageSliderProps {
  images: IImage[];
  withLightbox?: boolean;
  className?: string;
  title?: string;
  fullBleed?: boolean;
}

// Temporarily removed Lightbox functionality due to move to Keen carousel library
export const ImageSlider: React.FC<ImageSliderProps> = ({
  images,
  className,
  title,
  fullBleed,
}) => {
  const initialSlideIndex = 0;
  const [imagesLoaded, setImagesLoaded] = useState(0);
  const [currentIndex, setCurrentIndex] = useState(initialSlideIndex);
  const [sliderRef, instanceRef] = useKeenSlider({
    selector: ".slide",
    loop: true,
    initial: initialSlideIndex,
    slides: {
      perView: "auto",
      spacing: 8,
      origin: "center",
    },
    slideChanged(e) {
      setCurrentIndex(e.track.details.rel);
    },
  });

  const fullBleedClasses: CSSProperties = fullBleed
    ? {
        width: "100vw",
        position: "relative",
        marginLeft: "-50vw",
        left: "50%",
      }
    : {};

  // Keen Slider can only render loop layout after all images have been loaded, so it needs to be updated manually
  useEffect(() => {
    if (imagesLoaded >= images.length) {
      instanceRef.current?.update();
    }
  }, [imagesLoaded]);

  useEffect(() => {
    instanceRef.current?.update();
  }, []);

  return (
    <>
      {title && (
        <div className="container">
          <h3 className="font-inter sm:font-karla text-3xl md:text-5xl leading-9 md:leading-none font-normal text-grey-900 mb-6 md:mb-8">
            {title}
          </h3>
        </div>
      )}
      <div
        style={fullBleedClasses}
        ref={sliderRef}
        className={`flex min-h-full content-start overflow-hidden select-none touch-pan-y py-8 ${
          className || ""
        }`}
      >
        {images &&
          images.map((image, index) => {
            return (
              <Image
                key={image.id || index}
                className="relative slide"
                img={image.img}
                caption={
                  imagesLoaded >= images.length ? image.caption : undefined
                }
                subCaption={
                  imagesLoaded >= images.length ? image.subCaption : undefined
                }
                tag={image.tag}
                onClick={() => {
                  setCurrentIndex(index);
                  instanceRef?.current?.moveToIdx(index);
                }}
                faded={!(index === currentIndex)}
                onLoad={() => {
                  setImagesLoaded((prev) => prev + 1);
                }}
                inSlider
              />
            );
          })}
      </div>
      {/* {withLightbox && (
          <Lightbox
             isOpen={isLightboxOpen}
             images={images}
             currentImage={currentImage}
             onClose={() => setIsLightboxOpen(false)}
           />
         )} */}
    </>
  );
};
