import React from "react";
import GitlabLogo from "@assets/images/socialMedia/gitlab-color.svg";
import GithubLogo from "@assets/images/socialMedia/github.svg";

interface RepoCardProps {
  project: string;
  projectTitle: string;
  description: string;
  className?: string;
  target: string;
  platform: "gitlab" | "github";
  stats?: Array<{
    value: string | number;
    icon: React.ReactElement;
  }>;
}

const platformIconMapping = {
  gitlab: GitlabLogo,
  github: GithubLogo,
};

export const RepoCard: React.FC<RepoCardProps> = ({
  project,
  projectTitle,
  description,
  className,
  platform,
  stats,
  target,
}) => {
  return (
    <div className="not-prose">
      <a
        href={target}
        target="_blank"
        rel="noreferrer"
        className={`bg-grey-100 flex gap-2 p-4 md:p-8 ${className || ""}`}
      >
        <div className="flex flex-col md:gap-2 flex-1">
          <h5 className="font-karla font-normal text-base md:text-3xl md:leading-8 text-grey-900 ">
            {project} /{" "}
            <span className="font-bold hover:multi-line-underline multi-line-grey-900">
              {projectTitle}
            </span>
          </h5>
          <p className="font-plex text-sm md:text-lg text-grey-500 line-clamp-3">
            {description}
          </p>
          {stats && (
            <div className="hidden md:flex gap-12 pt-2">
              {stats.map((stat, index) => (
                <div
                  className="text-sm md:text-lg md:leading-7 text-grey-900"
                  key={index}
                >
                  {stat.icon &&
                    (typeof stat.value === "number" || stat.value) && (
                      <div className="flex justify-center items-center gap-2">
                        {stat.icon}
                        {stat.value}
                      </div>
                    )}
                </div>
              ))}
            </div>
          )}
        </div>
        {Boolean(platformIconMapping[platform]) && (
          <div className="py-3 md:py-5 flex justify-end">
            <img
              className="w-8 md:w-11 h-8 md:h-11"
              alt={platform}
              src={platformIconMapping[platform]}
            />
          </div>
        )}
      </a>
    </div>
  );
};
