import * as React from "react";
import type { Story } from "@ladle/react";
import { Header } from "@components/Header/Header";
import {
  ChoroplethMap,
  Folders,
  Chat,
  Calendar,
  ApplicationVirtual,
  Email,
  UserAvatar,
  Notification,
} from "@carbon/icons-react";
import { ITopBarItem, IToolbarItem } from "@interfaces/IHeader";
import { useState } from "react";
import BurgerLogoBlack from "@assets/images/Burger_Logo_black.svg";
import BurgerLogoWhite from "@assets/images/Burger_Logo_white.svg";

const TOPBAR_ITEMS: ITopBarItem[] = [
  {
    title: "Fab City Hamburg",
    target: "/",
    children: [
      {
        title: "FCHH Association",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
          {
            title: "L3 Item 5",
            target: "/",
          },
        ],
      },
      {
        title: "Hamburg 2054",
        target: "/",
      },
      {
        title: "Members",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
      {
        title: "Career",
        target: "/",
      },
      {
        title: "Blog",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
    ],
  },
  {
    title: "Network",
    target: "/",
    children: [
      {
        title: "Map",
        target: "/",
      },
      {
        title: "Fab Labs",
        target: "/",
      },
      {
        title: "Unternehmen",
        target: "/",
      },
      {
        title: "Community",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
      {
        title: "Fab City Global",
        target: "/",
      },
    ],
  },
  {
    title: "Projects",
    target: "/",
    children: [
      {
        title: "Kalender",
        target: "/",
      },
      {
        title: "Workshops",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
      {
        title: "Prototype Session",
        target: "/",
      },
      {
        title: "Fab Friday",
        target: "/",
      },
      {
        title: "Maker Challenge 2022",
        target: "/",
      },
    ],
  },
  {
    title: "Research",
    target: "/",
    children: [
      {
        title: "Fab City OS",
        target: "/",
      },
      {
        title: "Open Lab Starter Kit",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
      {
        title: "FarmBot Hamburg",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
          {
            title: "L3 Item 5",
            target: "/",
          },
        ],
      },
      {
        title: "Fab City Incubator",
        target: "/",
      },
      {
        title: "Fab City Index",
        target: "/",
      },
    ],
  },
  {
    title: "Contact",
    target: "/",
  },
];

const TOOLBAR_ITEMS: IToolbarItem[] = [
  {
    title: "Map",
    icon: (
      <ChoroplethMap className="w-6 sm:w-5 h-6 sm:h-5 sm:mr-2 mb-1 sm:mb-0" />
    ),
    target: "/map",
  },
  {
    title: "Knowledge Hub",
    icon: <Folders className="w-6 sm:w-5 h-6 sm:h-5 sm:mr-2 mb-1 sm:mb-0" />,
    target: "/hub",
    onlyDesktop: true,
  },
  {
    title: "Connect",
    icon: <Chat className="w-6 sm:w-5 h-6 sm:h-5 sm:mr-2 mb-1 sm:mb-0" />,
    target: "/connect",
  },
  {
    title: "Events",
    icon: <Calendar className="w-6 sm:w-5 h-6 sm:h-5 sm:mr-2 mb-1 sm:mb-0" />,
    target: "/events",
  },
  {
    title: "FCOS Core",
    icon: (
      <ApplicationVirtual className="w-6 sm:w-5 h-6 sm:h-5 sm:mr-2 mb-1 sm:mb-0" />
    ),
    target: "/map",
  },
];

const EXTENDED_TOOLBAR_ITEMS: IToolbarItem[] = [
  {
    title: "Email",
    icon: <Email size={24} />,
    target: "/email",
  },
  {
    title: "Notification",
    icon: <Notification size={24} />,
    target: "/notification",
  },
  {
    title: "User",
    icon: <UserAvatar size={24} />,
    target: "/user",
  },
];

interface HeaderConfigProps {
  itemsAlwaysLight: boolean;
  customLogo: boolean;
  toolBar: boolean;
  logoAlwaysInTopBar: boolean;
  logoLinkTarget: string;
}

/* eslint-disable react/prop-types */
export const HeaderStory: Story<HeaderConfigProps> = ({
  logoAlwaysInTopBar,
  itemsAlwaysLight,
  customLogo,
  toolBar,
  logoLinkTarget
}) => {
  const languages = ["de", "en"];
  const [selectedLanguage, setSelectedLanguage] = useState(languages[0]);
  return (
    <>
      <div className="bg-grey-500 w-screen h-screen relative" />
      <Header
        topBarItems={TOPBAR_ITEMS}
        toolBarItems={toolBar ? TOOLBAR_ITEMS : []}
        extendedToolBarItems={EXTENDED_TOOLBAR_ITEMS}
        languages={languages}
        selectedLanguage={selectedLanguage}
        onChangeLanguage={(newLanguage) => {
          console.log("New language selected: ", newLanguage);
          setSelectedLanguage(newLanguage);
        }}
        onSearch={(keyword) => console.log("Search for: ", keyword)}
        itemsAlwaysLight={itemsAlwaysLight}
        customLogo={
          customLogo
            ? [BurgerLogoBlack as string, BurgerLogoWhite as string]
            : undefined
        }
        logoAlwaysInTopBar={logoAlwaysInTopBar}
        logoLinkTarget={logoLinkTarget}
      />
    </>
  );
};

HeaderStory.args = {
  itemsAlwaysLight: false,
  customLogo: false,
  logoAlwaysInTopBar: false,
  toolBar: true,
  logoLinkTarget: "https://www.google.de"
};

export default {
  title: "Organisms",
};

HeaderStory.storyName = "Header";
